# Enhanced FRS

The enhanced FRS goes through three stages of generation:

1. Extension - the FRS is processed, and then duplicated twice: (FRS, FRS with full UC migration, FRS with SPI-imputed income variables and FRS with SPI-imputed income and UC migration).
2. Calibration - household weights from the produced dataset are calibrated to hit administrative statistics.
3. Imputation - consumption and wealth variables are imputed from the LCFS and WAS respectively, sampling from distributions so as to preserve weighted totals.
